==> cljs-time-0.5.0-20170303.221901-2.jar: cljs_test/generated_test_suite.out/jx/reporter/karma.js <==
// Compiled by ClojureScript 1.9.89 {:static-fns true, :optimize-constants true, :target :nodejs}
goog.provide('jx.reporter.karma');
goog.require('cljs.core');
goog.require('cljs.test');
jx.reporter.karma.karma = cljs.core.volatile_BANG_(null);
jx.reporter.karma.karma_QMARK_ = (function jx$reporter$karma$karma_QMARK_(){
return !(((cljs.core.deref.cljs$core$IFn$_invoke$arity$1 ? cljs.core.deref.cljs$core$IFn$_invoke$arity$1(jx.reporter.karma.karma) : cljs.core.deref.call(null,jx.reporter.karma.karma)) == null));
});
jx.reporter.karma.karma_info_BANG_ = (function jx$reporter$karma$karma_info_BANG_(m){
return (cljs.core.deref.cljs$core$IFn$_invoke$arity$1 ? cljs.core.deref.cljs$core$IFn$_invoke$arity$1(jx.reporter.karma.karma) : cljs.core.deref.call(null,jx.reporter.karma.karma)).info(cljs.core.clj__GT_js(m));
});
jx.reporter.karma.karma_result_BANG_ = (function jx$reporter$karma$karma_result_BANG_(m){
return (cljs.core.deref.cljs$core$IFn$_invoke$arity$1 ? cljs.core.deref.cljs$core$IFn$_invoke$arity$1(jx.reporter.karma.karma) : cljs.core.deref.call(null,jx.reporter.karma.karma)).result(cljs.core.clj__GT_js(m));
});
jx.reporter.karma.karma_complete_BANG_ = (function jx$reporter$karma$karma_complete_BANG_(){
return (cljs.core.deref.cljs$core$IFn$_invoke$arity$1 ? cljs.core.deref.cljs$core$IFn$_invoke$arity$1(jx.reporter.karma.karma) : cljs.core.deref.call(null,jx.reporter.karma.karma)).complete(cljs.core.clj__GT_js(cljs.core.PersistentArrayMap.EMPTY));
});
jx.reporter.karma.now = (function jx$reporter$karma$now(){
return (new Date()).getTime();
});
jx.reporter.karma.test_var_result = cljs.core.volatile_BANG_(cljs.core.PersistentVector.EMPTY);
jx.reporter.karma.test_var_time_start = cljs.core.volatile_BANG_(jx.reporter.karma.now());
cljs.test.report.cljs$core$IMultiFn$_add_method$arity$3(null,cljs.core.cst$kw$karma,(function (m){
return null;
}));
cljs.test.report.cljs$core$IMultiFn$_add_method$arity$3(null,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$jx$reporter$karma_SLASH_karma,cljs.core.cst$kw$begin_DASH_test_DASH_var], null),(function (m){
return cljs.core.vreset_BANG_(jx.reporter.karma.test_var_result,cljs.core.PersistentVector.EMPTY);
}));
cljs.test.report.cljs$core$IMultiFn$_add_method$arity$3(null,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$jx$reporter$karma_SLASH_karma,cljs.core.cst$kw$end_DASH_test_DASH_var], null),(function (m){
var var_meta = cljs.core.meta(cljs.core.cst$kw$var.cljs$core$IFn$_invoke$arity$1(m));
var result = new cljs.core.PersistentArrayMap(null, 6, ["suite",new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$ns.cljs$core$IFn$_invoke$arity$1(var_meta)], null),"description",cljs.core.cst$kw$name.cljs$core$IFn$_invoke$arity$1(var_meta),"success",(cljs.core.count((cljs.core.deref.cljs$core$IFn$_invoke$arity$1 ? cljs.core.deref.cljs$core$IFn$_invoke$arity$1(jx.reporter.karma.test_var_result) : cljs.core.deref.call(null,jx.reporter.karma.test_var_result))) === (0)),"skipped",null,"time",(jx.reporter.karma.now() - (cljs.core.deref.cljs$core$IFn$_invoke$arity$1 ? cljs.core.deref.cljs$core$IFn$_invoke$arity$1(jx.reporter.karma.test_var_time_start) : cljs.core.deref.call(null,jx.reporter.karma.test_var_time_start))),"log",cljs.core.map.cljs$core$IFn$_invoke$arity$2(((function (var_meta){
return (function (p1__16721_SHARP_){
return [cljs.core.str("Fail "),cljs.core.str(cljs.test.testing_vars_str(p1__16721_SHARP_)),cljs.core.str("\n"),cljs.core.str("Expected "),cljs.core.str(cljs.core.pr_str.cljs$core$IFn$_invoke$arity$variadic(cljs.core.array_seq([cljs.core.cst$kw$expected.cljs$core$IFn$_invoke$arity$1(p1__16721_SHARP_)], 0))),cljs.core.str("\n"),cljs.core.str("Actual: "),cljs.core.str(cljs.core.pr_str.cljs$core$IFn$_invoke$arity$variadic(cljs.core.array_seq([cljs.core.cst$kw$actual.cljs$core$IFn$_invoke$arity$1(p1__16721_SHARP_)], 0))),cljs.core.str("\n")].join('');
});})(var_meta))
,(cljs.core.deref.cljs$core$IFn$_invoke$arity$1 ? cljs.core.deref.cljs$core$IFn$_invoke$arity$1(jx.reporter.karma.test_var_result) : cljs.core.deref.call(null,jx.reporter.karma.test_var_result)))], null);
if(cljs.core.truth_(jx.reporter.karma.karma_QMARK_())){
return jx.reporter.karma.karma_result_BANG_(result);
} else {
return null;
}
}));
cljs.test.report.cljs$core$IMultiFn$_add_method$arity$3(null,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$jx$reporter$karma_SLASH_karma,cljs.core.cst$kw$fail], null),(function (m){
cljs.test.inc_report_counter_BANG_(cljs.core.cst$kw$fail);

return cljs.core._vreset_BANG_(jx.reporter.karma.test_var_result,cljs.core.conj.cljs$core$IFn$_invoke$arity$2(cljs.core._deref(jx.reporter.karma.test_var_result),m));
}));
cljs.test.report.cljs$core$IMultiFn$_add_method$arity$3(null,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$jx$reporter$karma_SLASH_karma,cljs.core.cst$kw$error], null),(function (m){
cljs.test.inc_report_counter_BANG_(cljs.core.cst$kw$error);

return cljs.core._vreset_BANG_(jx.reporter.karma.test_var_result,cljs.core.conj.cljs$core$IFn$_invoke$arity$2(cljs.core._deref(jx.reporter.karma.test_var_result),m));
}));
cljs.test.report.cljs$core$IMultiFn$_add_method$arity$3(null,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$jx$reporter$karma_SLASH_karma,cljs.core.cst$kw$end_DASH_run_DASH_tests], null),(function (m){
if(cljs.core.truth_(jx.reporter.karma.karma_QMARK_())){
return jx.reporter.karma.karma_complete_BANG_();
} else {
return null;
}
}));
jx.reporter.karma.start = (function jx$reporter$karma$start(tc,total_count){
cljs.core.vreset_BANG_(jx.reporter.karma.karma,tc);

if(cljs.core.truth_(jx.reporter.karma.karma_QMARK_())){
return jx.reporter.karma.karma_info_BANG_(new cljs.core.PersistentArrayMap(null, 1, [cljs.core.cst$kw$total,total_count], null));
} else {
return null;
}
});

==> cljs-time-0.5.0-20170416.034543-1.jar: cljs_test/generated_test_suite.out/jx/reporter/karma.js <==
// Compiled by ClojureScript 1.9.521 {:static-fns true, :optimize-constants true, :target :nodejs}
goog.provide('jx.reporter.karma');
goog.require('cljs.core');
goog.require('cljs.core.constants');
goog.require('cljs.test');
jx.reporter.karma.karma = cljs.core.volatile_BANG_(null);
jx.reporter.karma.karma_QMARK_ = (function jx$reporter$karma$karma_QMARK_(){
return !(((cljs.core.deref.cljs$core$IFn$_invoke$arity$1 ? cljs.core.deref.cljs$core$IFn$_invoke$arity$1(jx.reporter.karma.karma) : cljs.core.deref.call(null,jx.reporter.karma.karma)) == null));
});
jx.reporter.karma.karma_info_BANG_ = (function jx$reporter$karma$karma_info_BANG_(m){
return (cljs.core.deref.cljs$core$IFn$_invoke$arity$1 ? cljs.core.deref.cljs$core$IFn$_invoke$arity$1(jx.reporter.karma.karma) : cljs.core.deref.call(null,jx.reporter.karma.karma)).info(cljs.core.clj__GT_js(m));
});
jx.reporter.karma.karma_result_BANG_ = (function jx$reporter$karma$karma_result_BANG_(m){
return (cljs.core.deref.cljs$core$IFn$_invoke$arity$1 ? cljs.core.deref.cljs$core$IFn$_invoke$arity$1(jx.reporter.karma.karma) : cljs.core.deref.call(null,jx.reporter.karma.karma)).result(cljs.core.clj__GT_js(m));
});
jx.reporter.karma.karma_complete_BANG_ = (function jx$reporter$karma$karma_complete_BANG_(){
return (cljs.core.deref.cljs$core$IFn$_invoke$arity$1 ? cljs.core.deref.cljs$core$IFn$_invoke$arity$1(jx.reporter.karma.karma) : cljs.core.deref.call(null,jx.reporter.karma.karma)).complete(cljs.core.clj__GT_js(cljs.core.PersistentArrayMap.EMPTY));
});
jx.reporter.karma.now = (function jx$reporter$karma$now(){
return (new Date()).getTime();
});
jx.reporter.karma.test_var_result = cljs.core.volatile_BANG_(cljs.core.PersistentVector.EMPTY);
jx.reporter.karma.test_var_time_start = cljs.core.volatile_BANG_(jx.reporter.karma.now());
cljs.test.report.cljs$core$IMultiFn$_add_method$arity$3(null,cljs.core.cst$kw$karma,(function (m){
return null;
}));
cljs.test.report.cljs$core$IMultiFn$_add_method$arity$3(null,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$jx$reporter$karma_SLASH_karma,cljs.core.cst$kw$begin_DASH_test_DASH_var], null),(function (m){
return cljs.core.vreset_BANG_(jx.reporter.karma.test_var_result,cljs.core.PersistentVector.EMPTY);
}));
cljs.test.report.cljs$core$IMultiFn$_add_method$arity$3(null,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$jx$reporter$karma_SLASH_karma,cljs.core.cst$kw$end_DASH_test_DASH_var], null),(function (m){
var var_meta = cljs.core.meta(cljs.core.cst$kw$var.cljs$core$IFn$_invoke$arity$1(m));
var result = new cljs.core.PersistentArrayMap(null, 6, ["suite",new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$ns.cljs$core$IFn$_invoke$arity$1(var_meta)], null),"description",cljs.core.cst$kw$name.cljs$core$IFn$_invoke$arity$1(var_meta),"success",(cljs.core.count((cljs.core.deref.cljs$core$IFn$_invoke$arity$1 ? cljs.core.deref.cljs$core$IFn$_invoke$arity$1(jx.reporter.karma.test_var_result) : cljs.core.deref.call(null,jx.reporter.karma.test_var_result))) === (0)),"skipped",null,"time",(jx.reporter.karma.now() - (cljs.core.deref.cljs$core$IFn$_invoke$arity$1 ? cljs.core.deref.cljs$core$IFn$_invoke$arity$1(jx.reporter.karma.test_var_time_start) : cljs.core.deref.call(null,jx.reporter.karma.test_var_time_start))),"log",cljs.core.map.cljs$core$IFn$_invoke$arity$2(((function (var_meta){
return (function (p1__18521_SHARP_){
return [cljs.core.str.cljs$core$IFn$_invoke$arity$1("Fail "),cljs.core.str.cljs$core$IFn$_invoke$arity$1(cljs.test.testing_vars_str(p1__18521_SHARP_)),cljs.core.str.cljs$core$IFn$_invoke$arity$1("\n"),cljs.core.str.cljs$core$IFn$_invoke$arity$1("Expected "),cljs.core.str.cljs$core$IFn$_invoke$arity$1(cljs.core.pr_str.cljs$core$IFn$_invoke$arity$variadic(cljs.core.array_seq([cljs.core.cst$kw$expected.cljs$core$IFn$_invoke$arity$1(p1__18521_SHARP_)], 0))),cljs.core.str.cljs$core$IFn$_invoke$arity$1("\n"),cljs.core.str.cljs$core$IFn$_invoke$arity$1("Actual: "),cljs.core.str.cljs$core$IFn$_invoke$arity$1(cljs.core.pr_str.cljs$core$IFn$_invoke$arity$variadic(cljs.core.array_seq([cljs.core.cst$kw$actual.cljs$core$IFn$_invoke$arity$1(p1__18521_SHARP_)], 0))),cljs.core.str.cljs$core$IFn$_invoke$arity$1("\n")].join('');
});})(var_meta))
,(cljs.core.deref.cljs$core$IFn$_invoke$arity$1 ? cljs.core.deref.cljs$core$IFn$_invoke$arity$1(jx.reporter.karma.test_var_result) : cljs.core.deref.call(null,jx.reporter.karma.test_var_result)))], null);
if(cljs.core.truth_(jx.reporter.karma.karma_QMARK_())){
return jx.reporter.karma.karma_result_BANG_(result);
} else {
return null;
}
}));
cljs.test.report.cljs$core$IMultiFn$_add_method$arity$3(null,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$jx$reporter$karma_SLASH_karma,cljs.core.cst$kw$fail], null),(function (m){
cljs.test.inc_report_counter_BANG_(cljs.core.cst$kw$fail);

return cljs.core._vreset_BANG_(jx.reporter.karma.test_var_result,cljs.core.conj.cljs$core$IFn$_invoke$arity$2(cljs.core._deref(jx.reporter.karma.test_var_result),m));
}));
cljs.test.report.cljs$core$IMultiFn$_add_method$arity$3(null,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$jx$reporter$karma_SLASH_karma,cljs.core.cst$kw$error], null),(function (m){
cljs.test.inc_report_counter_BANG_(cljs.core.cst$kw$error);

return cljs.core._vreset_BANG_(jx.reporter.karma.test_var_result,cljs.core.conj.cljs$core$IFn$_invoke$arity$2(cljs.core._deref(jx.reporter.karma.test_var_result),m));
}));
cljs.test.report.cljs$core$IMultiFn$_add_method$arity$3(null,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$jx$reporter$karma_SLASH_karma,cljs.core.cst$kw$end_DASH_run_DASH_tests], null),(function (m){
if(cljs.core.truth_(jx.reporter.karma.karma_QMARK_())){
return jx.reporter.karma.karma_complete_BANG_();
} else {
return null;
}
}));
jx.reporter.karma.start = (function jx$reporter$karma$start(tc,total_count){
cljs.core.vreset_BANG_(jx.reporter.karma.karma,tc);

if(cljs.core.truth_(jx.reporter.karma.karma_QMARK_())){
return jx.reporter.karma.karma_info_BANG_(new cljs.core.PersistentArrayMap(null, 1, [cljs.core.cst$kw$total,total_count], null));
} else {
return null;
}
});
